API_TOKEN_HEADER = 'api_token'

TLS_CLIENT_CRT = "client.crt"
TLS_CLIENT_KEY = "client.key"
TLS_TRUSTED_CERTS = ["trusted.crt", ]
